==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/rendering/TextBoxTrimmer.h <==
/**
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/LocalFrameViewLayoutContext.h>
#include <wtf/CheckedPtr.h>

namespace WebCore {

class TextBoxTrimmer {
public:
    TextBoxTrimmer(const RenderBlockFlow& blockContainer);
    TextBoxTrimmer(const RenderBlockFlow& blockContainer, const RenderBlockFlow& lastFormattedLineRoot);
    ~TextBoxTrimmer();

    static RenderBlockFlow* lastInlineFormattingContextRootForTrimEnd(const RenderBlockFlow& blockContainer);

private:
    void adjustTextBoxTrimStatusBeforeLayout(const RenderBlockFlow* lastFormattedLineRoot);
    void adjustTextBoxTrimStatusAfterLayout();
    void handleTextBoxTrimNoneBeforeLayout();

    CheckedPtr<const RenderBlockFlow> m_blockContainer;
    std::optional<LocalFrameViewLayoutContext::TextBoxTrim> m_previousTextBoxTrimStatus { };
    bool m_shouldRestoreTextBoxTrimStatus { false };
};

}

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/rendering/TextBoxTrimmer.h <==
/**
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/LocalFrameViewLayoutContext.h>
#include <wtf/CheckedPtr.h>

namespace WebCore {

class TextBoxTrimmer {
public:
    TextBoxTrimmer(const RenderBlockFlow& blockContainer);
    TextBoxTrimmer(const RenderBlockFlow& blockContainer, const RenderBlockFlow& lastFormattedLineRoot);
    ~TextBoxTrimmer();

    static CheckedPtr<RenderBlockFlow> lastInlineFormattingContextRootForTrimEnd(const RenderBlockFlow& blockContainer);

private:
    void adjustTextBoxTrimStatusBeforeLayout(const RenderBlockFlow* lastFormattedLineRoot);
    void adjustTextBoxTrimStatusAfterLayout();
    void handleTextBoxTrimNoneBeforeLayout();

    CheckedPtr<const RenderBlockFlow> m_blockContainer;
    std::optional<LocalFrameViewLayoutContext::TextBoxTrim> m_previousTextBoxTrimStatus { };
    bool m_shouldRestoreTextBoxTrimStatus { false };
};

class TextBoxTrimStartDisabler {
public:
    TextBoxTrimStartDisabler(const RenderBox&);
    ~TextBoxTrimStartDisabler();

private:
    CheckedPtr<const RenderBox> m_renderBox;
    std::optional<LocalFrameViewLayoutContext::TextBoxTrim> m_previousTextBoxTrimStatus { };
};

}
